pub enum InitHint {
JoystickHatButtons(bool),
CocoaChdirResources(bool),
CocoaMenubar(bool),
}Expand description
Initialization hints that can be set using the init_hint function.
Variants
JoystickHatButtons(bool)
Specifies whether to also expose joystick hats as buttons, for compatibility with earlier
versions of GLFW that did not have glfwGetJoystickHats.
CocoaChdirResources(bool)
Specifies whether to set the current directory to the application to the Contents/Resources
subdirectory of the application’s bundle, if present.
This is ignored on platforms besides macOS.
CocoaMenubar(bool)
Specifies whether to create a basic menu bar, either from a nib or manually, when the first window is created, which is when AppKit is initialized.
This is ignored on platforms besides macOS.